searchData={"items":[{"type":"module","title":"BMP280","doc":"Read temperature and pressure from a Bosch BM280, BME280, or BME680 sensor","ref":"BMP280.html"},{"type":"function","title":"BMP280.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"BMP280.html#child_spec/1"},{"type":"function","title":"BMP280.detect/2","doc":"Detect the type of sensor that is located at the I2C address\n\nIf the sensor is a known BMP280 or BME280 the response will either contain\n`:bmp280` or `:bme280`. If the sensor does not report back that it is one of\nthose two types of sensors the return value will contain the id value that\nwas reported back form the sensor.\n\nThe bus address is likely going to be 0x77 (the default) or 0x76.","ref":"BMP280.html#detect/2"},{"type":"function","title":"BMP280.force_altitude/2","doc":"Force the altitude to a known value\n\nAltitude calculations depend on the accuracy of the sea level pressure estimate. Since\nthe sea level pressure changes based on the weather, it needs to be kept up to date\nor altitude measurements can be pretty far off. Another way to set the sea level pressure\nis to report a known altitude. Call this function with the current altitude in meters.\n\nThis function returns an error if the attempt to sample the current barometric\npressure fails.","ref":"BMP280.html#force_altitude/2"},{"type":"function","title":"BMP280.measure/1","doc":"Measure the current temperature, pressure, altitude\n\nAn error is return if the I2C transactions fail.","ref":"BMP280.html#measure/1"},{"type":"function","title":"BMP280.read/1","doc":"","ref":"BMP280.html#read/1"},{"type":"function","title":"BMP280.sensor_type/1","doc":"Return the type of sensor\n\nThis function returns the cached result of reading the ID register.\nif the part is recognized. If not, it returns the integer read.","ref":"BMP280.html#sensor_type/1"},{"type":"function","title":"BMP280.start_link/1","doc":"Start a new GenServer for interacting with a BMP280\n\nNormally, you'll want to pass the `:bus_name` option to specify the I2C\nbus going to the BMP280.","ref":"BMP280.html#start_link/1"},{"type":"function","title":"BMP280.update_sea_level_pressure/2","doc":"Update the sea level pressure estimate\n\nThe sea level pressure should be specified in Pascals. The estimate\nis used for altitude calculations.","ref":"BMP280.html#update_sea_level_pressure/2"},{"type":"type","title":"BMP280.options/0","doc":"BMP280 GenServer start_link options\n\n* `:name` - a name for the GenServer\n* `:bus_name` - which I2C bus to use (e.g., `\"i2c-1\"`)\n* `:bus_address` - the address of the BMP280 (defaults to 0x77)\n* `:sea_level_pa` - a starting estimate for the sea level pressure in Pascals","ref":"BMP280.html#t:options/0"},{"type":"type","title":"BMP280.sensor_type/0","doc":"The type of sensor in use\n\nIf the sensor is unknown, then number in the parts ID register is used.","ref":"BMP280.html#t:sensor_type/0"},{"type":"module","title":"BMP280.Measurement","doc":"One sensor measurement report\n\nThe temperature, pressure and relative humidity measurements are computed\ndirectly from the sensor. All other values are derived.","ref":"BMP280.Measurement.html"},{"type":"type","title":"BMP280.Measurement.t/0","doc":"","ref":"BMP280.Measurement.html#t:t/0"},{"type":"extras","title":"BMP280","doc":"# BMP280\n\n[![Hex version](https://img.shields.io/hexpm/v/bmp280.svg \"Hex version\")](https://hex.pm/packages/bmp280)\n[![CircleCI](https://circleci.com/gh/elixir-sensors/bmp280.svg?style=svg)](https://circleci.com/gh/elixir-sensors/bmp280)\n\nRead temperature and pressure from Bosch\nBMP180,\n[BMP280](https://www.bosch-sensortec.com/products/environmental-sensors/pressure-sensors/bmp280/),\n[BME280](https://www.bosch-sensortec.com/products/environmental-sensors/humidity-sensors-bme280/),\nand\n[BME680](https://www.bosch-sensortec.com/products/environmental-sensors/gas-sensors-bme680/)\nsensors in Elixir.","ref":"readme.html"},{"type":"extras","title":"Usage - BMP280","doc":"Here's an example use (most sensors are at address 0x77, but some are at 0x76):\n\n```elixir\niex> {:ok, bmp} = BMP280.start_link(bus_name: \"i2c-1\", bus_address: 0x77)\n{:ok, #PID }\niex> BMP280.measure(bmp)\n{:ok,\n %BMP280.Measurement{\n   altitude_m: 138.96206905098805,\n   dew_point_c: 2.629181073094435,\n   gas_resistance_ohms: 5279.474749704044,\n   humidity_rh: 34.39681642351278,\n   pressure_pa: 100818.86273677988,\n   temperature_c: 18.645856498100876,\n   timestamp_ms: 885906\n }}\n```\n\nDepending on your hardware configuration, you may need to modify the call to\n`BMP280.start_link/1`. See `t:BMP280.options/0` for parameters.\n\nAll measurements are reported in SI units.\n\nThe altitude measurement is computed from the measured barometric pressure. To\nbe accurate, it requires either the current sea level pressure or the current\naltitude. Here's an example:\n\n```elixir\niex> BMP280.force_altitude(bmp, 100)\n:ok\n```\n\nSubsequent altitude reports should be more accurate until the weather changes.","ref":"readme.html#usage"},{"type":"extras","title":"Nerves Livebook Firmware - BMP280","doc":"[Nerves Livebook Firmware](https://github.com/fhunleth/nerves_livebook) contains BMP280 example, which shows you how to work with the BMP280 sensor on the [Nerves](https://www.nerves-project.org/) projects with example code that is runnable from the comfort of your browser.","ref":"readme.html#nerves-livebook-firmware"},{"type":"extras","title":"BMP3XX - BMP280","doc":"Please check out this other Elixir library [BMP3XX](https://hex.pm/packages/bmp3xx) for Bosch [BMP388](https://www.bosch-sensortec.com/products/environmental-sensors/pressure-sensors/bmp388/) and [BMP390](https://www.bosch-sensortec.com/products/environmental-sensors/pressure-sensors/bmp390/) sensors.","ref":"readme.html#bmp3xx"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.2.13 - Changelog","doc":"* Changes\n  * Relax circuits_i2c dependency to allow v2.0","ref":"changelog.html#v0-2-13"},{"type":"extras","title":"v0.2.12 - Changelog","doc":"* Improvements\n  * Update online documentation using ex_doc 0.29\n  * Bump elixir versions in ci","ref":"changelog.html#v0-2-12"},{"type":"extras","title":"v0.2.11 - Changelog","doc":"* Improvements\n  * Support both circuits_i2c 1.0 and 0.3.x","ref":"changelog.html#v0-2-11"},{"type":"extras","title":"v0.2.10 - Changelog","doc":"* Fixes\n  * Fix dew point calculation from raising when sensor can't measure the\n    relative humidity","ref":"changelog.html#v0-2-10"},{"type":"extras","title":"v0.2.9 - Changelog","doc":"* New features\n  * Add BMP180 support","ref":"changelog.html#v0-2-9"},{"type":"extras","title":"v0.2.8 - Changelog","doc":"* Improvements\n  * Mention BMP3XX in readme\n  * Log helpful message on init\n  * Add credo as a code quality tool\n  * Refactor comm modules in a way they can focus on communicating with the device\n\n* Fixes\n  * Fix typespec links in the hexdoc","ref":"changelog.html#v0-2-8"},{"type":"extras","title":"v0.2.7 - Changelog","doc":"* Improvements\n  * Update Circle config for OTP 24\n  * Remove the \"Support for other Bosch barometric sensors\" section from README\n\n* Fixes\n  * Halt the sensor initialization when device is not found","ref":"changelog.html#v0-2-7"},{"type":"extras","title":"v0.2.6 - Changelog","doc":"* Improvements\n  * Make README.md the main doc page\n  * Add \"Nerves Livebook Firmware\" section to README.md\n\n* Fixes\n  * Fix broken CI link","ref":"changelog.html#v0-2-6"},{"type":"extras","title":"v0.2.5 - Changelog","doc":"* New features\n  * Stable basic gas support\n\n* API changes\n  * none\n\n* Improvements\n  * Restructure internal code organization.\n  * Change ambient temperature estimate from `30 C` to `25 C` for setting up gas measurements\n\n* Fixes\n  * Sleep 10 ms after soft reset so that the sensor data can be read properly.\n  * Correct the parser for gas-related calibration data. Previously, some data types were wrong.\n  * Fix a broken link to BMP280 sensor in README.","ref":"changelog.html#v0-2-5"},{"type":"extras","title":"v0.2.4 - Changelog","doc":"This release adds support for reading the BME680's gas resistance sensor. In the\nfuture, this will be converted to an indoor air quality measurement.\n\n* API changes\n  * Sensor measurements are now obtained by calling `BMP280.measure/1` for\n    consistency with other Elixir sensor libraries. `BMP280.read/1` is\n    deprecated.\n\n* Improvements\n  * The library now polls the sensor once a second. Calls to `BMP280.measure/1`\n    return the latest reading rather than making an I2C transaction.\n  * Measurements now include a timestamp (`System.monotonic_time(:millisecond)`)\n  * Various internal code improvements to make it easier to support many Bosch\n    sensors","ref":"changelog.html#v0-2-4"},{"type":"extras","title":"v0.2.3 - Changelog","doc":"* New features\n  * Support temperature, humidity and pressure measurements on the BME680. VOC\n    measurements are not supported yet.","ref":"changelog.html#v0-2-3"},{"type":"extras","title":"v0.2.2 - Changelog","doc":"Note: This release removes the non-SI conversion helper functions. They were\ninconsistently defined, and it seems better for some other library to care more\nabout conversions.\n\n* New features\n  * Add dew point approximation","ref":"changelog.html#v0-2-2"},{"type":"extras","title":"v0.2.1 - Changelog","doc":"* Bug fixes\n  * Fix `BMP280.detect/2` so that it only probes one I2C bus address.","ref":"changelog.html#v0-2-1"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"* New features\n  * Add support for the BME280 and for reading relative humidity measurements\n    from it","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.1 - Changelog","doc":"* Fixes\n  * Fixed `:bus_address` parameter. It was incorrectly referred to as `:address`\n    when used.","ref":"changelog.html#v0-1-1"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial release","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown"}